@@ -7,12 +7,10 @@ which in turn needs access to this version inpackion.)
 
 Credit is given to fabric, whose version.py is the basis for this module.
 """
-from __future__ import print_function
-from builtins import str
 from subprocess import Popen, PIPE
 from os.path import abspath, dirname
 
-VERSION = (0, 22, 0, 'final', 0)
+VERSION = (0, 23, 0, 'final', 0)
 
 def git_sha():
     loc = abspath(dirname(__file__))
